#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['dategen']

package_data = \
{'': ['*']}

setup(name='dategen',
      version='1.0.2',
      description='A date generator.',
      author='Chang-Ming Chen',
      author_email='changming.chen.1970@gmail.com',
      url='https://codeberg.org/cmc/dategen',
      packages=packages,
      package_data=package_data,
     )
